@@ -21,6 +21,7 @@ USER_PROFILES_DIR = "/etc/tuned/profiles"
 SYSTEM_PROFILES_DIR = "/usr/lib/tuned/profiles"
 PERSISTENT_STORAGE_DIR = "/var/lib/tuned"
 PLUGIN_MAIN_UNIT_NAME = "main"
+PLUGIN_VARIABLES_UNIT_NAME = "variables"
 # Magic section header because ConfigParser does not support "headerless" config
 MAGIC_HEADER_NAME = "this_is_some_magic_section_header_because_of_compatibility"
 RECOMMEND_DIRECTORIES = ["/usr/lib/tuned/recommend.d", "/etc/tuned/recommend.d"]
@@ -43,7 +44,6 @@ GRUB2_DEFAULT_ENV_FILE = "/etc/default/grub"
 INITRD_IMAGE_DIR = "/boot"
 BOOT_CMDLINE_TUNED_VAR = "TUNED_BOOT_CMDLINE"
 BOOT_CMDLINE_INITRD_ADD_VAR = "TUNED_BOOT_INITRD_ADD"
-BOOT_CMDLINE_KARGS_DELETED_VAR = "TUNED_BOOT_KARGS_DELETED"
 BOOT_CMDLINE_FILE = "/etc/tuned/bootcmdline"
 PETITBOOT_DETECT_DIR = "/sys/firmware/opal"
 MACHINE_ID_FILE = "/etc/machine-id"
@@ -106,17 +106,17 @@ PPD_API_COMPATIBILITY = "0.23"
 PPD_DBUS_BUS = "org.freedesktop.UPower.PowerProfiles"
 PPD_DBUS_BUS_LEGACY = "net.hadess.PowerProfiles"
 PPD_DBUS_NAMES = [
-    {
-        "bus": PPD_DBUS_BUS,
-        "namespace": PPD_DBUS_BUS,
-        "interface": PPD_DBUS_BUS,
-        "object": "/org/freedesktop/UPower/PowerProfiles"
+	{
+		"bus": PPD_DBUS_BUS,
+		"namespace": PPD_DBUS_BUS,
+		"interface": PPD_DBUS_BUS,
+		"object": "/org/freedesktop/UPower/PowerProfiles"
 	},
-    {
-        "bus": PPD_DBUS_BUS_LEGACY,
-        "namespace": PPD_DBUS_BUS_LEGACY,
-        "interface": PPD_DBUS_BUS_LEGACY,
-        "object": "/net/hadess/PowerProfiles"
+	{
+		"bus": PPD_DBUS_BUS_LEGACY,
+		"namespace": PPD_DBUS_BUS_LEGACY,
+		"interface": PPD_DBUS_BUS_LEGACY,
+		"object": "/net/hadess/PowerProfiles"
 	}
 ]
 
@@ -130,6 +130,7 @@ CFG_SLEEP_INTERVAL = "sleep_interval"
 CFG_UPDATE_INTERVAL = "update_interval"
 CFG_RECOMMEND_COMMAND = "recommend_command"
 CFG_REAPPLY_SYSCTL = "reapply_sysctl"
+CFG_REAPPLY_SYSCTL_EXCLUDE = "reapply_sysctl_exclude"
 CFG_DEFAULT_INSTANCE_PRIORITY = "default_instance_priority"
 CFG_UDEV_BUFFER_SIZE = "udev_buffer_size"
 CFG_LOG_FILE_COUNT = "log_file_count"
@@ -146,6 +147,7 @@ CFG_UNIX_SOCKET_CONNECTIONS_BACKLOG = "connections_backlog"
 CFG_CPU_EPP_FLAG = "hwp_epp"
 CFG_ROLLBACK = "rollback"
 CFG_PROFILE_DIRS = "profile_dirs"
+CFG_STARTUP_UDEV_SETTLE_WAIT = "startup_udev_settle_wait"
 
 # no_daemon mode
 CFG_DEF_DAEMON = True
@@ -165,6 +167,8 @@ CFG_FUNC_RECOMMEND_COMMAND = "getboolean"
 # reapply system sysctl
 CFG_DEF_REAPPLY_SYSCTL = True
 CFG_FUNC_REAPPLY_SYSCTL = "getboolean"
+# sysctl parameters to exclude from reapplication
+CFG_DEF_REAPPLY_SYSCTL_EXCLUDE = []
 # default instance priority
 CFG_DEF_DEFAULT_INSTANCE_PRIORITY = 0
 CFG_FUNC_DEFAULT_INSTANCE_PRIORITY = "getint"
@@ -197,6 +201,8 @@ CFG_FUNC_UNIX_SOCKET_CONNECTIONS_BACKLOG = "getint"
 CFG_DEF_ROLLBACK = "auto"
 # default profile directories
 CFG_DEF_PROFILE_DIRS = [SYSTEM_PROFILES_DIR, USER_PROFILES_DIR]
+# default startup udev settle wait
+CFG_DEF_STARTUP_UDEV_SETTLE_WAIT = 0
 
 PATH_CPU_DMA_LATENCY = "/dev/cpu_dma_latency"
 
